@@ -3,22 +3,11 @@
 #include "error.h"
 #include "Handle.h"
 #include "Request.h"
+#include "Ssl.h"
 #include <panda/unievent/Stream.h>
 
 namespace xs {
 
-template <> struct Typemap<SSL_CTX*> : TypemapBase<SSL_CTX*> {
-    static SSL_CTX* in (SV* arg) {
-        if (!SvOK(arg)) return nullptr;
-        return reinterpret_cast<SSL_CTX*>(SvIV(arg));
-    }
-
-    static Sv out (SSL_CTX* ctx, const Sv& = Sv()) {
-        if (!ctx) return Simple::undef;
-        return Simple(reinterpret_cast<ptrdiff_t>(ctx));
-    }
-};
-
 template <class TYPE> struct Typemap<panda::unievent::Stream*, TYPE> : Typemap<panda::unievent::BackendHandle*, TYPE> {};
 
 template <class TYPE> struct Typemap<panda::unievent::ConnectRequest*, TYPE> : Typemap<panda::unievent::Request*, TYPE> {
